@@ -10,12 +10,12 @@ impl Inspectable for ExampleWidget {
         &mut self,
         _: &mut bevy_inspector_egui::egui::Ui,
         _: Self::Attributes,
-        _: &bevy_inspector_egui::Context,
+        _: &mut bevy_inspector_egui::Context,
     ) -> bool {
         false
     }
 
-    fn setup(_: &mut AppBuilder) {
+    fn setup(_: &mut App) {
         eprintln!("Running setup code...");
 
         // app.init_resource::<WhateverYouNeed>();
@@ -28,7 +28,7 @@ struct Data {
 }
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<Data>::new());
 }
