@@ -3,7 +3,9 @@ mod inspectable_registry;
 mod plugin;
 
 use bevy::{
-    ecs::archetype::Archetype, reflect::TypeRegistration, render::camera::Camera, ui::FocusPolicy,
+    ecs::archetype::Archetype,
+    reflect::TypeRegistration,
+    render::camera::{Camera2d, Camera3d},
     window::WindowId,
 };
 pub use inspectable_registry::InspectableRegistry;
@@ -185,7 +187,7 @@ impl<'a> WorldUIContext<'a> {
             .unwrap_or(true);
 
         if show_entity {
-            CollapsingHeader::new(entity_name.to_string())
+            CollapsingHeader::new(entity_name)
                 .id_source(id.with(entity))
                 .show(ui, |ui| {
                     self.entity_ui_inner(ui, entity, params, id, entity_options)
@@ -597,6 +599,7 @@ unsafe fn get_component_and_ticks(
     }
 }
 
+#[allow(unused)]
 macro_rules! is_bundle {
     ($entity:ident: $($ty:ty),* $(,)?) => {
         $( $entity.contains::<$ty>() && )* true
@@ -618,21 +621,28 @@ fn guess_entity_name_inner(entity: EntityRef) -> String {
 
     let id = entity.id().id();
 
-    if let Some(camera) = entity.get::<Camera>() {
-        match &camera.name {
-            Some(name) => return name.to_string(),
-            None => return format!("Camera ({})", id),
-        }
+    if entity.get::<Camera3d>().is_some() {
+        return format!("Camera3d ({})", id);
+    }
+    if entity.get::<Camera2d>().is_some() {
+        return format!("Camera2d ({})", id);
+    }
+    #[cfg(feature = "bevy_ui")]
+    if entity.get::<bevy::ui::entity::CameraUi>().is_some() {
+        return format!("CameraUi ({})", id);
     }
 
+    #[cfg(feature = "bevy_pbr")]
     if is_bundle!(entity: PointLight, Transform, GlobalTransform) {
         return format!("Light ({})", id);
     }
 
+    #[cfg(feature = "bevy_pbr")]
     if is_bundle!(entity: DirectionalLight, Transform, GlobalTransform) {
         return format!("Directional Light ({})", id);
     }
 
+    #[cfg(feature = "bevy_pbr")]
     if is_bundle!(
         entity: Handle<Mesh>,
         Handle<StandardMaterial>,
@@ -642,17 +652,12 @@ fn guess_entity_name_inner(entity: EntityRef) -> String {
         return format!("Pbr Mesh ({})", id);
     }
 
-    if is_bundle!(
-        entity: Node,
-        Style,
-        Text,
-        CalculatedSize,
-        FocusPolicy,
-        Transform,
-        GlobalTransform
-    ) {
+    #[cfg(feature = "bevy_text")]
+    if is_bundle!(entity: Text, Transform, GlobalTransform) {
         return format!("Text ({})", id);
     }
+
+    #[cfg(feature = "bevy_text")]
     if is_bundle!(
         entity: Text,
         Transform,
@@ -661,6 +666,8 @@ fn guess_entity_name_inner(entity: EntityRef) -> String {
     ) {
         return format!("Text2d ({})", id);
     }
+
+    #[cfg(feature = "bevy_ui")]
     if is_bundle!(
         entity: Node,
         Style,
